package fr.openium.consentium_ui.data.di

import dagger.Lazy
import dagger.Module
import dagger.Provides
import dagger.Reusable
import dagger.hilt.InstallIn
import dagger.hilt.components.SingletonComponent
import fr.openium.consentium.data.di.ConsentiumUrl
import fr.openium.consentium.data.di.OkHttpClientDefault
import fr.openium.consentium_ui.BuildConfig
import fr.openium.consentium_ui.data.remote.ConsentiumUIApi
import fr.openium.consentium_ui.data.remote.mock.ConsentiumUIMockApi
import kotlinx.serialization.json.Json
import okhttp3.HttpUrl
import okhttp3.MediaType.Companion.toMediaType
import okhttp3.OkHttpClient
import retrofit2.Retrofit
import retrofit2.converter.kotlinx.serialization.asConverterFactory

private val json by lazy {
    Json {
        isLenient = true
        ignoreUnknownKeys = true
    }
}

@Module
@InstallIn(SingletonComponent::class)
internal object NetworkModule {

    @Reusable
    @Provides
    fun provideConsentiumUIApi(
        @ConsentiumUrl url: HttpUrl,
        @OkHttpClientDefault okHttpClient: Lazy<OkHttpClient>,
    ): ConsentiumUIApi = if (BuildConfig.FLAVOR != "demo") {
        createRetrofit(
            url,
            okHttpClient
        ).create(ConsentiumUIApi::class.java)
    } else {
        ConsentiumUIMockApi
    }

    private fun createRetrofit(url: HttpUrl, okHttpClient: Lazy<OkHttpClient>): Retrofit =
        Retrofit.Builder()
            .callFactory { request ->
                okHttpClient.get().newCall(request)
            }.addConverterFactory(json.asConverterFactory("application/json".toMediaType()))
            .baseUrl(url)
            .build()

}
