package fr.openium.consentium_ui.ui.components.core

import androidx.compose.foundation.clickable
import androidx.compose.foundation.interaction.MutableInteractionSource
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.width
import androidx.compose.material3.CircularProgressIndicator
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.remember
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.text.style.TextDecoration
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import fr.openium.consentium_ui.ui.components.style.ConsentiumUITheme

@Composable
internal fun TextLink(
    text: String,
    onclick: () -> Unit,
    color: Color = ConsentiumUITheme.colors.primary,
    isLoading: Boolean = false,
) {
    val interactionSource = remember { MutableInteractionSource() }

    Row(
        modifier = Modifier
            .clickable(
                interactionSource = interactionSource,
                indication = null,
                onClick = onclick,
            )
    ) {
        Text(
            text = text,
            color = color,
            style = ConsentiumUITheme.typography.b3,
            textDecoration = TextDecoration.Underline
        )

        if (isLoading) {
            Spacer(modifier = Modifier.width(10.dp))

            CircularProgressIndicator(
                color = color,
                modifier = Modifier.size(14.dp),
                strokeWidth = 3.dp
            )
        }
    }

}

@Preview
@Composable
private fun TextLinkPreview() {
    TextLink(
        text = "Continuer sans accepter",
        onclick = {},
        isLoading = true,
    )
}